/*
sitemap04.js
Copyright (c) 2008 Jeff D. Conrad

Makes use of:
	wz_jsgraphics.js
	v. 3.03     
	@see http://www.walterzorn.com/jsgraphics/jsgraphics_e.htm
          
	prototype.js       
	v. 1.6.0.3 
	@see http://www.prototypejs.org/

LICENSE: LGPL

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License (LGPL) as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA,
or see http://www.gnu.org/copyleft/lesser.html
*/

var Sitemap = {
	jg: null,
	baseurl: null,
	sitepages: null,
	pageId: null,
	canvasId: null,
	
	initialize: function(pageId, canvasId) {
		var s=window.location.search+"";
		if (s.length > 1) {
			s = s.substring(1, s.length);
			s = s.split("=")[1];
			var sitemapSite = $('sitemapSite');
			var o = new Option();
			o.text = s;			
			i = sitemapSite.options.length;
			sitemapSite.options[i] = o;
			sitemapSite.selectedIndex = i;
		}
		this.pageId = pageId;
		this.canvasId = canvasId;
		var cnv = $(canvasId);
		this.jg = new jsGraphics(cnv);
		this.jg.setPrintable(true);
	},
	pageLoad: function(pageId, canvasId) {
		this.initialize(pageId, canvasId);
		this.loadStructure();
	},
	loadStructure: function() {
		[this.pageId, this.canvasId].each(Element.hide);
		var sitemapSite = $F('sitemapSite');
		var url = sitemapSite + ".xml?t=" + (new Date()).getTime();
		new Ajax.Request(url, { method:'get',
								onSuccess: function(transport) {
									var xmlDocument = transport.responseXML;
									Sitemap.loadXml(xmlDocument);
									var sitepage = Sitemap.sitepages[0];
									Sitemap.renderSitepage(sitepage);
								}
							  }
		);
	},
	loadXml: function(xmlDocument) {
		try {
			var sitestructureElems = xmlDocument.getElementsByTagName("sitestructure");
			sitestructureElem = sitestructureElems[0];
			var baseurl = sitestructureElem.getAttribute("baseurl");
			this.baseurl = baseurl;

			var sitepageElems = sitestructureElem.getElementsByTagName("sitepage");
			var sitepageLen = sitepageElems.length;
			
			var sitepages = new Array();
			for (var i=0; i<sitepageLen; i++) {
				var sitepage = new Sitepage();
				sitepage.initializeXML(sitepageElems[i]);
				sitepages.push(sitepage);
			}
			this.sitepages = sitepages;
		} catch (e) {
			alert("Error loading xml", e);
		}
	},
	renderSitepage: function(sitepage) {
		var html = "";
		var sitepagesLen = this.sitepages.length;
		if (sitepagesLen == 1) {
			html += "<b>" + sitepage.name + "</b>";
		} else {
			for (var i=0;i<sitepagesLen;i++) {
				var searchSitepage = this.sitepages[i];
				if (sitepage != searchSitepage) {
					html += "<a href=\"#\" onclick=\"Sitemap.renderSitepage(Sitemap.sitepages[" + i + "]);\">" + (i+1) + ": " + searchSitepage.name + "</a>";
				} else {
					html += "<b>" + (i+1) + ": " + searchSitepage.name + "</b>";
				}
				html += "&nbsp;&nbsp;&nbsp;";
			}
		}
		$(this.pageId).innerHTML = html;
	
		var jg = this.jg;
		jg.clear();

		var siteareaLen = sitepage.siteareas ? sitepage.siteareas.length : 0;
		for(var i=0; i<siteareaLen; i++) {
			var sitearea = sitepage.siteareas[i];
			this.renderSitearea(sitearea, jg);
		}
		jg.paint();
		[this.pageId, this.canvasId].each(Element.show);
	},
	renderSitearea: function(sitearea, jg) {
		jg.setColor(sitearea.fillcolor);
		jg.fillRect(sitearea.x, sitearea.y, sitearea.width, sitearea.height);

		jg.setColor(sitearea.linecolor);
		jg.drawRect(sitearea.x, sitearea.y, sitearea.width, sitearea.height);
		
		jg.setColor("#333333");
		jg.setFont("Arial", "11px", Font.BOLD);
		jg.drawString("Area: " + this.truncate(sitearea.name), sitearea.x + 2, sitearea.y + 2);
		
		var pagesLen = sitearea.pages.length;
		for(var i=0; i<pagesLen; i++) {
			var page = sitearea.pages[i];
			this.renderSiteareaPage(page, sitearea, jg);
		}
	},
	renderSiteareaPage: function(page, sitearea, jg) {
		jg.setColor("#ffffff");
		jg.fillRect(sitearea.x + page.x + 10, sitearea.y + page.y + 20, page.width, page.height);

		jg.setColor("#666666");
		jg.drawRect(sitearea.x + page.x + 10, sitearea.y + page.y + 20, page.width, page.height);
		
		jg.setFont("Arial", "10px", Font.PLAIN);
		jg.drawString(this.truncate(page.name), sitearea.x + page.x + 20, sitearea.y + page.y + 24);
		
		jg.setFont("Arial", "9px", Font.ITALIC);
		jg.drawString("<a href=\"" + page.url + "\">(" + this.truncate(page.url) + ")</a>", sitearea.x + page.x + 20, sitearea.y + page.y + 40);
	},
	truncate: function(str) {
		if (str.length > 25) {
			str = str.substring(0,22)+'...';
		}
		return str;
	}
}

var Sitepage = Class.create();
Sitepage.prototype = {
	name: null,
	siteareas: null,
  
    initialize: function() {
	},
  	initializeXML: function(xml) {
		this.name = xml.getAttribute("name");
		
		// get sitearea XML elements
		var siteareaElems = xml.getElementsByTagName("sitearea");
		var siteareaLen = siteareaElems.length;
		
		// create siteareas array
		var siteareas = new Array();
		for (var i=0; i<siteareaLen; i++) {
			var sitearea = new Sitearea();
			sitearea.initializeXML(siteareaElems[i]);
			siteareas.push(sitearea);
		}
		this.siteareas = siteareas;
	},
	toString: function() {
		return "Sitepage[" 
			+ " name[" + this.name + "]"
		    + " siteareas[" + this.siteareas + "]"
		+ "]";
	}
};

var Positionable = Class.create();
Positionable.prototype = {
	name: null,
	x: 0,
	y: 0,
	width: 0,
	height: 0,
  
    initialize: function() {
	},
	initializeXML: function(xml) {
		this.initializeXML_Positionable();
	},
  	initializeXML_Positionable: function(xml) {
		this.name = xml.getAttribute("name");
		this.x = parseInt(xml.getAttribute("x"),10);
		this.y = parseInt(xml.getAttribute("y"),10);
		this.width = parseInt(xml.getAttribute("width"),10);
		this.height = parseInt(xml.getAttribute("height"),10);
	},
	toString: function() {
		return "Positionable[" 
		       + this.toString_Positionable();
		       + "]";
	},
	toString_Positionable: function() {
		return " name[" + this.name + "]"
		       + " x[" + this.x + "]"
		       + " y[" + this.y + "]"
		       + " width[" + this.width + "]"
		       + " height[" + this.height + "]"
		;
	}
};

var Sitearea = Class.create();
Sitearea.prototype = Object.extend(new Positionable(), {
	pages: null,
	fillcolor: null,
	linecolor: null,
  
    initialize: function() {
	},
  	initializeXML: function(xml) {
		this.initializeXML_Positionable(xml);
		this.fillcolor = xml.getAttribute("fillcolor");
		this.linecolor = xml.getAttribute("linecolor");
				
		// get page XML elements
		var pageElems = xml.getElementsByTagName("page");
		var pageLen = pageElems.length;
		
		// create pages array
		var pages = new Array();
		for (var i=0; i<pageLen; i++) {
			var page = new Page();
			page.initializeXML(pageElems[i]);
			pages.push(page);
		}
		this.pages = pages;
	},
	toString: function() {
		return "Sitearea[" 
		       + this.toString_Positionable()
		       + " pages[" + this.pages + "]"
		       + " fillcolor[" + this.fillcolor + "]"
		       + " linecolor[" + this.linecolor + "]"
		       + "]";
	}
});

var Page = Class.create();
Page.prototype = Object.extend(new Positionable(), {
	url: null,
	
	initialize: function() {
	},
	initializeXML: function(xml) {
		this.initializeXML_Positionable(xml);
		this.url = xml.getAttribute("url");
	},
	toString: function() {
		return "Page[" 
		       + this.toString_Positionable()
		       + " url[" + this.url + "]"
		+ "]";
	}
});

